from unittest import TestCase
from commonconf import settings, override_settings
from restclients_core.thread import is_django_mysql


class TestThread(TestCase):
    def test_is_django_mysql(self):
        with override_settings(DATABASES=None):
            self.assertFalse(is_django_mysql())

        with override_settings(DATABASES='mysql'):
            self.assertFalse(is_django_mysql())

        with override_settings(
                DATABASES={'default': {
                    'ENGINE': 'django.db.backends.sqlite3'}}):
            self.assertFalse(is_django_mysql())

        with override_settings(
                DATABASES={'default': {
                    'ENGINE': 'django.db.backends.mysql'}}):
            self.assertTrue(is_django_mysql())



from unittest import TestCase
from restclients_core.util import urlencode, url_with_query


class TestURLUtils(TestCase):

    def test_url_with_query(self):
        params = {'student_id': 1033334, 'year': 2014, 'term_name': 'Autumn'}
        IAS_PREFIX = "/api/v1/evaluation"

        url = url_with_query(IAS_PREFIX, params)

        self.assertEqual(url, "/api/v1/evaluation?student_id=1033334"
                         "&term_name=Autumn&year=2014")

        params = {'student_id': 1033334, 'year': 2014, 'term_name': 'Autumn',
                  'alpha': 'omega'}

        url = url_with_query(IAS_PREFIX, params)

        self.assertEqual(url, "/api/v1/evaluation?alpha=omega&"
                         "student_id=1033334&term_name=Autumn&year=2014")

    def test_urlencode_dict(self):
        params = {'student_id': 1033334, 'year': 2014, 'term_name': 'Autumn'}
        url = urlencode(params)
        self.assertEqual(url, "student_id=1033334&term_name=Autumn&year=2014")

    def test_urlencode_tuple_list(self):
        params = [('student_id', 1033334), ('year', 2014),
                  ('term_name', 'Autumn')]

        url = urlencode(params)
        self.assertEqual(url, "student_id=1033334&term_name=Autumn&year=2014")



import sys
try:
    from urllib import quote_plus
    from urllib import urlencode as urllib_encode
except ImportError:
    from urllib.parse import urlencode as urllib_encode
    from urllib.parse import quote_plus


def url_with_query(base, params):
    """
    Takes in a base url and a group of parameters/query, and returns a
    formatted url. Will be consistent between python 2 and 3.
    """
    return base + "?%s" % urlencode(params)


def urlencode(query, doseq=True, safe='', encoding=None, errors=None,
              quote_via=quote_plus):
    """
    This is a utility method used to ensure that the query params are sorted
    consistently between python2 and python3 by urlencode.
    """
    if type(query) is dict:
        query = [(key, query[key]) for key in sorted(query.keys())]
    elif type(query) is list:
        query = sorted(query, key=lambda tup: tup[0])

    if (sys.version_info > (3, 5)):
        return urllib_encode(query, doseq, safe, encoding, errors, quote_via)
    elif (sys.version_info == (3, 4)):
        return urllib_encode(query, doseq, safe, encoding, errors)
    else:
        return urllib_encode(query, doseq)
